## Detector Parameters

This is a [yaml](https://yaml.org/) file hosting the fixed characteristics of the soxs detectors such as gain, science-pixel indexes and image orientations.

Having these characteristics in a plain-text yaml file allows them to be abstracted from the main code and helps maintain a single-source of truth.

